Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(561)

Unified Diff: components/password_manager/core/common/credential_manager_types.h

Issue 1851933002: Convert //url to use std::unique_ptr (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: IWYU fixup 7 Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/password_manager/core/common/credential_manager_types.h
diff --git a/components/password_manager/core/common/credential_manager_types.h b/components/password_manager/core/common/credential_manager_types.h
index 98503f9bce8d967b54445a399052c18bc199ac92..dbe84fdddecb7d21be8c124f5b8c66b2b2787d67 100644
--- a/components/password_manager/core/common/credential_manager_types.h
+++ b/components/password_manager/core/common/credential_manager_types.h
@@ -7,6 +7,7 @@
#include <stddef.h>
+#include <memory>
#include <string>
#include "base/compiler_specific.h"
@@ -63,8 +64,9 @@ struct CredentialInfo {
};
// Create a new autofill::PasswordForm object based on |info|, valid in the
-// context of |origin|. Returns an empty scoped_ptr for CREDENTIAL_TYPE_EMPTY.
-scoped_ptr<autofill::PasswordForm> CreatePasswordFormFromCredentialInfo(
+// context of |origin|. Returns an empty std::unique_ptr for
+// CREDENTIAL_TYPE_EMPTY.
+std::unique_ptr<autofill::PasswordForm> CreatePasswordFormFromCredentialInfo(
const CredentialInfo& info,
const GURL& origin);
« no previous file with comments | « components/ntp_snippets/ntp_snippet.cc ('k') | content/browser/notifications/notification_database_data_conversions.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698